<!--降雨量雨积水次数统计-->
<template>
  <div class="rainfall-accumulation">
    <public-title title="降雨量雨积水次数统计" />
    <div class="chart-container">
      <div
        id="rainfall-accumulation-chart"
        style="width: 100%; height: 100%"
      />
    </div>
    <div class="search-cont">
      年份：
      <el-date-picker
        v-model="searchValue"
        value-format="yyyy"
        type="year"
        placeholder="选择统计年份"
        @change="getChartData"
        :editable="false"
        :clearable="false"
      >
      </el-date-picker>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import rainfallAccumulation from '@/api/device/rainfallAccumulation'
import PublicTitle from '../PublicTitle/index.vue'
import moment from 'moment'

export default {
  name: 'RainfallAccumulation',
  components: {PublicTitle},
  data() {
    return {
      myChart: null, // 图表实例对象
      historyArr: [], // 下钻数据历史
      searchValue: moment().format('YYYY')
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(
      document.getElementById('rainfall-accumulation-chart')
    )
  },
  methods: {
    /**
     * @function getChartData 获取图表数据
     * @return {void}
     * */
    getChartData() {
      rainfallAccumulation.rainAndWaterCount(
        {year: this.searchValue},
        (res) => {
          this.chartData = res.value
          this.$nextTick((_) => this.initEcharts())
        }
      )
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        tooltip: {
          trigger: 'axis',
          textStyle: {
            //---提示框样式
            color: '#606266',
            fontSize: '14'
          },
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow' // 默认为直线，可选为：'line' | 'shadow'
          }
        },
        legend: {
          type: 'plain',
          position: 'center',
          textStyle: {
            //---提示框样式
            color: '#606266',
            fontSize: '14'
          }
        },
        grid: {
          left: '0',
          right: '0',
          bottom: '0',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            axisTick: {show: true},
            axisLabel: {color: '#606266', fontSize: '14'},
            data: this.chartData.map((i) => i.collMonth)
          }
        ],
        yAxis: [
          {
            type: 'value',
            name: '降雨量（mm）',
            nameTextStyle: {
              color: '#606266',
              fontSize: '14',
              align: 'end',
              padding: [0, 0, 0, 0]
            },
            nameGap: 30,
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {color: '#606266', fontSize: '14'},
            // 修改y轴分割线
            splitLine: {
              lineStyle: {
                color: '#c7c7c7',
                fontSize: '14',
                type: 'dashed'
              }
            }
          },
          {
            type: 'value',
            name: '积水次数（次）',
            nameTextStyle: {
              color: '#606266',
              fontSize: '14',
              align: 'end',
              padding: [0, 0, 0, -90]
            },
            nameGap: 30,
            position: 'right',
            axisTick: {show: false},
            axisLine: {show: false},
            axisLabel: {color: '#606266', fontSize: '14'},
            // 修改y轴分割线
            splitLine: {
              lineStyle: {
                color: '#c7c7c7',
                fontSize: '14',
                type: 'dashed'
              }
            },
            splitLine: {
              //网格线
              show: false
            }
          }
        ],
        series: [
          {
            name: '降雨量',
            type: 'bar',
            barGap: '20%',
            barWidth: '35',
            yAxisIndex: 0,

            emphasis: {
              focus: 'series'
            },
            itemStyle: {
              color: '#3eadfd'
            },
            label: {
              show: true, //开启显示
              position: 'top', //在上方显示
              formatter: ({value}) => (value ? value : ''),
              textStyle: {
                //数值样式
                color: '#3eadfd', //字体颜色
                fontSize: 12 //字体大小
              }
            },
            data: this.chartData.map((i) => i.collDate)
          },
          {
            name: '积水次数',
            type: 'line',
            yAxisIndex: 1,

            barGap: '20%',
            itemStyle: {
              color: '#42ffe8'
            },
            data: this.chartData.map((i) => i.count)
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', (_) => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', (_) => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.rainfall-accumulation {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  position: relative;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }

  .search-cont {
    // width: 200px;
    position: absolute;
    right: 15px;
    top: 10px;
    // display: flex;
    // align-items: center;
  }
}
</style>
